@@ -30,7 +30,7 @@ $AR_EXTRAS = %{
   def self.V(n)
     @final = [n, @final.to_f].max
     m = (@migrations ||= [])
-    Class.new(ActiveRecord::Migration) do
+    Class.new(ActiveRecord::Migration[6.1]) do
       meta_def(:version) { n }
       meta_def(:inherited) { |k| m << k }
     end
@@ -54,7 +54,7 @@ $AR_EXTRAS = %{
           k.migrate(:up) if si.version < k.version and k.version <= opts[:version]
           k.migrate(:down) if si.version > k.version and k.version > opts[:version]
         end
-        si.update_attributes(:version => opts[:version])
+        si.update(:version => opts[:version])
       end
     end
   end
@@ -84,7 +84,7 @@ module Camping
     module_eval $AR_EXTRAS
   end
 end
-Camping::S.sub! /autoload\s*:Base\s*,\s*['"]camping\/ar['"]/, $AR_EXTRAS
+Camping::S.sub!(/autoload\s*:Base\s*,\s*['"]camping\/ar['"]/, $AR_EXTRAS)
 Camping::Apps.each do |c|
   c::Models.module_eval $AR_EXTRAS.gsub('Camping', c.to_s)
 end
